#
# spec file for package python-oslo.concurrency
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global sname oslo.concurrency
Name:           python-oslo.concurrency
Version:        3.14.0
Release:        1.2
Summary:        OpenStack oslo.concurrency library
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            https://launchpad.net/%{sname}
Source0:        https://pypi.io/packages/source/o/%{sname}/%{sname}-%{version}.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python-devel
BuildRequires:  python-enum34
BuildRequires:  python-eventlet >= 0.18.2
BuildRequires:  python-fasteners >= 0.7
BuildRequires:  python-fixtures >= 3.0.0
BuildRequires:  python-futures >= 3.0
BuildRequires:  python-mock >= 2.0
BuildRequires:  python-oslo.config >= 3.14.0
BuildRequires:  python-oslo.i18n >= 2.1.0
BuildRequires:  python-oslo.utils >= 3.16.0
BuildRequires:  python-oslotest >= 1.10.0
BuildRequires:  python-pbr >= 1.6
BuildRequires:  python-testrepository >= 0.0.18
BuildRequires:  python-testscenarios >= 0.4
BuildRequires:  python-testtools >= 1.4.0
Requires:       python-enum34
Requires:       python-fasteners >= 0.7
Requires:       python-iso8601 >= 0.1.11
Requires:       python-oslo.config >= 3.14.0
Requires:       python-oslo.i18n >= 2.1.0
Requires:       python-oslo.utils >= 3.16.0
Requires:       python-retrying >= 1.2.3
Requires:       python-six >= 1.9.0
BuildArch:      noarch

%description
The oslo.concurrency library has utilities for safely running multi-thread,
multi-process applications using locking mechanisms and for running
external processes.

%package doc
Summary:        Documentation for OpenStack concurrency library
Group:          Development/Languages/Python
BuildRequires:  python-Sphinx
BuildRequires:  python-oslosphinx >= 2.5.0

%description doc
The oslo.concurrency library has utilities for safely running multi-thread,
multi-process applications using locking mechanisms and for running
external processes.
This package contains the documentation.

%prep
%setup -q -n %{sname}-%{version}

%build
%{py2_build}

# generate html docs
%{__python2} setup.py build_sphinx
# remove the sphinx-build leftovers
rm -rf doc/build/html/.{doctrees,buildinfo}

%install
%{py2_install}

%check
# Test suite fails on 32 bit platforms
if [ "%_lib" = "lib64" ]; then
%{__python2} setup.py testr
fi

%files
%license LICENSE
%doc README.rst ChangeLog
%_bindir/lockutils-wrapper
%{python2_sitelib}/oslo_concurrency
%{python2_sitelib}/*.egg-info

%files doc
%license LICENSE
%doc doc/build/html

%changelog
* Tue Oct  4 2016 dmueller@suse.com
- switch to stable/newton
* Tue Aug 30 2016 tbechtold@suse.com
- update to version 3.14.0
  * Fix external lock tests on Windows
  * Updated from global requirements
* Wed Aug 10 2016 tbechtold@suse.com
- update to version 3.13.0
  * Add Python 3.5 classifier and venv
  * Imported Translations from Zanata
  * Fix parameters of assertEqual are misplaced
  * Updated from global requirements
  * Add reno for releasenotes management
* Fri Jun  3 2016 tbechtold@suse.com
- update to 3.9.0:
  * Add doc/ to pep8 check
  * Remove unused import statement
  * Add timeout option to ssh_execute
  * Fix wrong import example in docstring
  * Trivial: ignore openstack/common in flake8 exclude list
  * Updated from global requirements
  * Imported Translations from Zanata
  * processutils: add support for missing process limits
  * Remove direct dependency on babel
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Add a few usage examples for lockutils
  * Revert "Use tempfile.tempdir for lock_path if OSLO_LOCK_PATH is not set"
  * Updated from global requirements
  * Use tempfile.tempdir for lock_path if OSLO_LOCK_PATH is not set
* Thu Jun  2 2016 tbechtold@suse.com
- use renderspec source service
- update spec from upstream
* Mon Apr  4 2016 tbechtold@suse.com
- update to 3.7.0:
  * Updated from global requirements
  * Update .gitreview for stable/mitaka
- Adjust Requires
* Wed Mar 16 2016 tbechtold@suse.com
- Add python-enum34 as BuildRequires to fix tests
* Mon Feb 29 2016 dmueller@suse.com
- update to 3.6.0:
  * Updated from global requirements
  * Update translation setup
  * Add prlimit parameter to execute()
  * Imported Translations from Zanata
  * Remove unnecessary package in setup.cfg
* Sun Feb 28 2016 dmueller@suse.com
- update to 3.2.0:
  * Updated from global requirements
  * Trival: Remove 'MANIFEST.in'
  * Add complementary remove lock with prefix function
  * Drop python 2.6 support
  * Updated from global requirements
  * Remove python 2.6 classifier
  * Use versionadded and versionchanged in doc
  * Updated from global requirements
  * Imported Translations from Zanata
  * Fix Tests to run under OSX
  * Fix coverage configuration and execution
  * Imported Translations from Zanata
  * Move 'history' -> release notes section
  * add auto-generated docs for config options
  * Change ignore-errors to ignore_errors
  * Updated from global requirements
  * Imported Translations from Zanata
  * Use int enumerations for log error constants
* Wed Sep  9 2015 tbechtold@suse.com
- update to 2.6.0:
  * Removes unused posix-ipc requirement
  * Updated from global requirements
- Adjust Requires according to requirements.txt
* Thu Aug 27 2015 tbechtold@suse.com
- update to 2.5.0:
  * Updated from global requirements
  * Updated from global requirements
  * Use oslo_utils reflection to get 'f' callable name
  * flake8 - remove unused rules
  * Imported Translations from Transifex
  * Updated from global requirements
- Adjust Requires according to requirements.txt
* Wed Jul 29 2015 tbechtold@suse.com
- Unify spec file
- Add -doc package
* Mon Jul 20 2015 dmueller@suse.com
- update to 2.3.0:
  * Imported Translations from Transifex
  * Allow preexec_fn method for processutils.execute
  * Updated from global requirements
  * Use pypi name for requirements.txt
  * processutils: ensure on_completion callback is always called
  * Updated from global requirements
  * Remove redundant fileutils
  * Add tox target to find missing requirements
* Fri Jul  3 2015 dmueller@suse.com
- add missing dependency on fasteners
* Wed Jun 24 2015 tbechtold@suse.com
- update to 2.1.0:
  * Imported Translations from Transifex
  * Updated from global requirements
  * Updated from global requirements
  * Add 2 callbacks to processutils.execute()
  * Updated from global requirements
  * Fix LockFixture docstring
  * Updated from global requirements
  * Switch badges from 'pypip.in' to 'shields.io'
  * Updated from global requirements
  * Replace locks and replace with fasteners library provides ones
* Wed Jun 10 2015 tbechtold@suse.com
- update to 2.0.0:
  * Remove oslo namespace package
- enable testsuite
* Tue Jun  2 2015 tbechtold@suse.com
- update to 1.10.0:
  * Imported Translations from Transifex
  * Sync from oslo-incubator
  * Updated from global requirements
  * Advertise support for Python3.4 / Remove support for 3.3
  * Updated from global requirements
  * Imported Translations from Transifex
  * Remove run_cross_tests.sh
  * Updated from global requirements
  * Updated from global requirements
  * Add binary parameter to execute and ssh_execute
  * Port processutils to Python 3
  * Uncap library requirements for liberty
  * Move fixtures to test-requirements.txt
  * Fix test_as_root* tests to work when run as root
  * Add pypi download + version badges
  * Standardize setup.cfg summary for oslo libs
  * Imported Translations from Transifex
  * Updated from global requirements
  * Remove tools/run_cross_tests.sh from openstack-common.conf
* Mon Mar 30 2015 tbechtold@suse.com
- update to 1.8.0:
  * Switch to non-namespaced module imports
  * Remove py33 env from default tox list
  * Add lockutils.get_lock_path() function
* Tue Mar 10 2015 tbechtold@suse.com
- update to 1.7.0:
  * Imported Translations from Transifex
  * Updated from global requirements
- adjust Requires according to requirements.txt
* Tue Feb 24 2015 tbechtold@suse.com
- update to 1.6.0:
  * Updated from global requirements
  * processutils: execute(): fix option incompatibility
  * Ability to set working directory
  * Add eventlet test check to new tests __init__.py
  * Drop use of namespaced oslo.i18n
  * Updated from global requirements
  * Updated from global requirements
  * Update Oslo imports to remove namespace package
* Thu Jan 15 2015 tbechtold@suse.com
- update to 1.4.1:
  * Revert "Port processutils to Python 3"
* Wed Jan 14 2015 tbechtold@suse.com
- update to version 0.4.0:
  * Bump to hacking 0.10
  * Updated from global requirements
  * add watchdog module
  * Updated from global requirements
  * make time format for processutils match lockutils
  * Correct the translation domain for loading messages
  * Add a reader/writer lock
  * Don't use ConfigFilter for lockutils
  * Report import warnings where the import occurs
  * Port processutils to Python 3
  * Activate pep8 check that _ is imported
  * Drop requirements-py3.txt
  * Updated from global requirements
  * Clean up API documentation
  * Workflow documentation is now in infra-manual
  * Remove noqa from test files
  * test compatibility for old imports
  * Fix bug link in README.rst
- Adjust BuildRequires according to test-requirements.txt
* Wed Jan 14 2015 tbechtold@suse.com
- Add python_requires to _service
- Adjust Requires according to requirements.txt
* Tue Dec  9 2014 dmueller@suse.com
- update to 0.3.0:
  * Add external lock fixture
  * Add a TODO for retrying pull request #20
  * Allow the lock delay to be provided
  * Allow for providing a customized semaphore container
  * Move locale files to proper place
  * Flesh out the README
  * Move out of the oslo namespace package
  * Improve testing in py3 environment
  * Only modify autoindex.rst if it exists
  * Imported Translations from Transifex
  * lockutils-wrapper cleanup
  * Don't use variables that aren't initialized
* Sat Nov  1 2014 dmueller@suse.com
- Initial package
